#ifndef NT2_INCLUDE_FUNCTIONS_ERF_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_ERF_HPP_INCLUDED

#include <nt2/euler/include/functions/erf.hpp>

#endif
